pub struct Options {
pub log_prefix: bool,
pub stop_timeout: Duration,
pub poll: Duration,
}Fields
log_prefix: boolPrefix each output line with <service> | .
stop_timeout: DurationHow long a clean shutdown may take before the sandbox is killed.
poll: DurationHow often to check that the processes that started isb are still alive.