pub fn install_launch_agent(name: &str) -> Result<LaunchAgentInstall>Expand description
Write the LaunchAgent, load it (which starts the machine), and wait for the daemon in the machine to answer.
pub fn install_launch_agent(name: &str) -> Result<LaunchAgentInstall>Write the LaunchAgent, load it (which starts the machine), and wait for the daemon in the machine to answer.