pub struct Info {
pub addr: String,
pub ca_pem: String,
}Expand description
Where the registry is, as recorded on the system project (so any isb process with incus access finds it, the daemon’s state dir or not).
Fields
addr: String127.0.0.1:5480
ca_pem: StringImplementations