pub enum Manager {
Mise,
Cargo,
Npm,
Pip,
}Expand description
A package manager that owns an installed isb.
Variants
Implementations
Sourceimpl Manager
impl Manager
Sourcepub fn detect(exe: &Path) -> Option<Manager>
pub fn detect(exe: &Path) -> Option<Manager>
Which manager installed the binary at exe, judged by its path.
pub fn name(self) -> &'static str
Sourcepub fn upgrade_command(self) -> &'static str
pub fn upgrade_command(self) -> &'static str
The command that upgrades isb through this manager. For mise, the
installer: mise installs are deprecated (see Manager::deprecation).
Sourcepub fn deprecation(self) -> Option<String>
pub fn deprecation(self) -> Option<String>
Why an install by this manager should move to the installer, and how, if it should.