pub struct IdmapMap {
pub mode: IdmapMode,
pub host_uid: u32,
pub host_gid: u32,
pub guest_uid: u32,
pub guest_gid: u32,
}Fields
mode: IdmapModehost_uid: u32host_gid: u32guest_uid: u32guest_gid: u32Trait Implementations
Sourceimpl<'de> Deserialize<'de> for IdmapMap
impl<'de> Deserialize<'de> for IdmapMap
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for IdmapMap
impl JsonSchema for IdmapMap
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for IdmapMap