pub struct ResourceLimits {
pub cpus: Option<String>,
pub memory: Option<String>,
}Fields
cpus: Option<String>memory: Option<String>Trait Implementations
Sourceimpl Clone for ResourceLimits
impl Clone for ResourceLimits
Sourceimpl Debug for ResourceLimits
impl Debug for ResourceLimits
Sourceimpl Default for ResourceLimits
impl Default for ResourceLimits
Sourceimpl<'de> Deserialize<'de> for ResourceLimits
impl<'de> Deserialize<'de> for ResourceLimits
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ResourceLimits
impl JsonSchema for ResourceLimits
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ResourceLimits
impl PartialEq for ResourceLimits
Sourceimpl Serialize for ResourceLimits
impl Serialize for ResourceLimits
impl StructuralPartialEq for ResourceLimits