explain

Function explain 

pub fn explain(
    client: &Client,
    name: &str,
    service: &str,
    oci: bool,
    e: Error,
    now_ms: u64,
) -> (Error, FailedAttempt)
The failure of replica name with its last output in the message, and the attempt to keep. Called before the instance is deleted.