pub enum Action {
CreateVolume {
pool: String,
volume: String,
config: Props,
},
CreateInstance {
image: String,
pool: String,
config: Props,
devices: BTreeMap<String, Props>,
profiles: Vec<String>,
},
SetConfig {
key: String,
from: Option<String>,
to: String,
restart: bool,
secret: bool,
},
AddDevice {
device: String,
props: Props,
},
ReplaceDevice {
device: String,
replaces: String,
from: Props,
to: Props,
},
RemoveDevice {
device: String,
props: Props,
},
StartInstance,
AddPort {
device: String,
props: Props,
search: u16,
},
FixOwner {
path: String,
owner: String,
},
Note {
message: String,
},
}Expand description
One step of a plan.
Variants
CreateVolume
CreateInstance
Fields
SetConfig
Fields
AddDevice
ReplaceDevice
Replace a wrong device. For a disk that is a remount inside the guest.
Fields
RemoveDevice
StartInstance
AddPort
Add a host-bound proxy, moving up to search ports past a taken one.
FixOwner
Note
Something isb will not change (fixed at creation, or ambiguous). Informational.
Implementations